# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_project.ipynb.

# %% auto #0
__all__ = ['OVHProject']

# %% ../nbs/01_project.ipynb #46c7d6f2-2b91-4559-9cf8-bc2e807febd6
class OVHProject():
    def __init__(self, id:str, region:str=None, consumption_mode:str=None):
        """
        OVH Project class, storing project information

        Parameters
        ----------
        id : str, required
            OVH project id
        region : str, optional
            Project ressources region
        """
        self.id = id
        self.base_url = f'/cloud/project/{self.id}'
        self.region = None

    def set_region(self, region:str):
        """
        Sets the project's region

        Parameters
        ----------
        region : str, required
            Project ressources region
        """
        self.region = region

