# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/ovhmanager',
                'doc_host': 'https://hassoun.github.io',
                'git_url': 'https://github.com/hassoun/ovhmanager',
                'lib_path': 'ovhmanager'},
  'syms': { 'ovhmanager.catalog': { 'ovhmanager.catalog.GPUCatalog': ('catalog.html#gpucatalog', 'ovhmanager/catalog.py'),
                                    'ovhmanager.catalog.GPUCatalog.__init__': ('catalog.html#gpucatalog.__init__', 'ovhmanager/catalog.py'),
                                    'ovhmanager.catalog.GPUCatalog._list_addons': ( 'catalog.html#gpucatalog._list_addons',
                                                                                    'ovhmanager/catalog.py'),
                                    'ovhmanager.catalog.GPUCatalog._list_gpu_addons': ( 'catalog.html#gpucatalog._list_gpu_addons',
                                                                                        'ovhmanager/catalog.py'),
                                    'ovhmanager.catalog.GPUCatalog._list_project_plans': ( 'catalog.html#gpucatalog._list_project_plans',
                                                                                           'ovhmanager/catalog.py'),
                                    'ovhmanager.catalog.GPUCatalog.list_gpu_instances': ( 'catalog.html#gpucatalog.list_gpu_instances',
                                                                                          'ovhmanager/catalog.py')},
            'ovhmanager.core': { 'ovhmanager.core.OVHGPUManager': ('core.html#ovhgpumanager', 'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.__init__': ('core.html#ovhgpumanager.__init__', 'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.create_instance': ( 'core.html#ovhgpumanager.create_instance',
                                                                                    'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.get_instance': ( 'core.html#ovhgpumanager.get_instance',
                                                                                 'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.list_instances': ( 'core.html#ovhgpumanager.list_instances',
                                                                                   'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.list_projects': ( 'core.html#ovhgpumanager.list_projects',
                                                                                  'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.list_regions': ( 'core.html#ovhgpumanager.list_regions',
                                                                                 'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.retrieve_catalog_dict': ( 'core.html#ovhgpumanager.retrieve_catalog_dict',
                                                                                          'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.retrieve_gpu_flavor': ( 'core.html#ovhgpumanager.retrieve_gpu_flavor',
                                                                                        'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_consumption_mode': ( 'core.html#ovhgpumanager.select_consumption_mode',
                                                                                            'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_gpu_instance_type': ( 'core.html#ovhgpumanager.select_gpu_instance_type',
                                                                                             'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_instance_image': ( 'core.html#ovhgpumanager.select_instance_image',
                                                                                          'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_project': ( 'core.html#ovhgpumanager.select_project',
                                                                                   'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_region': ( 'core.html#ovhgpumanager.select_region',
                                                                                  'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_ssh_key': ( 'core.html#ovhgpumanager.select_ssh_key',
                                                                                   'ovhmanager/core.py')},
            'ovhmanager.instance': { 'ovhmanager.instance.GPUInstance': ('instance.html#gpuinstance', 'ovhmanager/instance.py'),
                                     'ovhmanager.instance.GPUInstance.__init__': ( 'instance.html#gpuinstance.__init__',
                                                                                   'ovhmanager/instance.py'),
                                     'ovhmanager.instance.GPUInstance.delete': ( 'instance.html#gpuinstance.delete',
                                                                                 'ovhmanager/instance.py'),
                                     'ovhmanager.instance.GPUInstance.display_details': ( 'instance.html#gpuinstance.display_details',
                                                                                          'ovhmanager/instance.py'),
                                     'ovhmanager.instance.GPUInstance.start': ('instance.html#gpuinstance.start', 'ovhmanager/instance.py'),
                                     'ovhmanager.instance.GPUInstance.stop': ('instance.html#gpuinstance.stop', 'ovhmanager/instance.py')},
            'ovhmanager.project': { 'ovhmanager.project.OVHProject': ('project.html#ovhproject', 'ovhmanager/project.py'),
                                    'ovhmanager.project.OVHProject.__init__': ('project.html#ovhproject.__init__', 'ovhmanager/project.py'),
                                    'ovhmanager.project.OVHProject.set_region': ( 'project.html#ovhproject.set_region',
                                                                                  'ovhmanager/project.py')}}}
